import { IsOptional } from "class-validator";
import { ChildEntity, ManyToOne, OneToMany } from "typeorm";
import { Address } from "./Address";
import { RunnerGroup } from "./RunnerGroup";
import { RunnerTeam } from "./RunnerTeam";

/**
 * Defines the RunnerOrganisation entity.
 * This usually is a school, club or company.
*/
@ChildEntity()
export class RunnerOrganisation extends RunnerGroup {

  /**
   * The organisations's address.
   */
  @IsOptional()
  @ManyToOne(() => Address, address => address.groups, { nullable: true })
  address?: Address;

  /**
   * The organisation's teams.
   * Used to link teams to a organisation.
   */
  @OneToMany(() => RunnerTeam, team => team.parentGroup, { nullable: true })
  teams: RunnerTeam[];
}